Estimate Out-of-Sample Concordance
estimate_concordance(
train,
test = train,
event_time = "event_time_years",
event_status = "mortstat",
weight_column = "WTMEC4YR_norm",
all_variables = NULL,
cfit_args = list(),
...
)A list of concordance and the model fit with the training data
A data set to perform model training.
A data set to estimate concordance, from fit model with train.
Set to train if estimating on the same data
Character vector of length 1 with event times, passed to
Surv
Character vector of length 1 with event status, passed to
Surv
Character vector of length 1 with weights for
model. If no weights are available, set to NULL
Character vector of variables to put in the
model. All must be in data.
Arguments passed to concordancefit. If
strata is to be passed, set strata_column in this list.
Additional arguments to pass to coxph